/* BdfServer - Copyright (c) 2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.externalsource;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.BdfServerConstants;
import fr.exemole.bdfserver.api.externalsource.ExternalSourceType;
import fr.exemole.bdfserver.api.externalsource.FichothequeSharing;
import java.util.ArrayList;
import java.util.List;
import net.fichotheque.thesaurus.Thesaurus;
import net.fichotheque.thesaurus.metadata.ThesaurusMetadata;


/**
 *
 * @author Vincent Calame
 */
public class CoreExternalSourceCatalog {

    public final static String FICHOTHEQUECORPUS_TYPENAME = "fichothequecorpus";
    public final static String WIKIDATA_TYPENAME = "wikidata";
    public final static ExternalSourceType FICHOTHEQUECORPUS = ExternalSourceTypeBuilder.init(FICHOTHEQUECORPUS_TYPENAME)
            .setL10nObject("_ title.external.fichothequecorpus")
            .addParam("fichotheque", "_ label.external.fichothequecorpus_fichotheque")
            .addParam("corpus", "_ label.external.fichothequecorpus_corpus")
            .toExternalSourceType();
    public final static ExternalSourceType WIKIDATA = ExternalSourceTypeBuilder.init(WIKIDATA_TYPENAME)
            .setL10nObject("_ title.external.wikidata")
            .toExternalSourceType();
    private final BdfServer bdfServer;
    private final boolean withFichothequeSharing;
    private final FichothequeSharing fichothequeSharing;

    public CoreExternalSourceCatalog(BdfServer bdfServer) {
        this.bdfServer = bdfServer;
        this.fichothequeSharing = (FichothequeSharing) bdfServer.getContextObject(BdfServerConstants.FICHOTHEQUESHARING_CONTEXTOBJECT);
        this.withFichothequeSharing = (fichothequeSharing != null);
    }

    public List<ExternalSourceType> getAvalaibleTypeList(Thesaurus thesaurus) {
        List<ExternalSourceType> result = new ArrayList<ExternalSourceType>();
        short thesaurusType = thesaurus.getThesaurusMetadata().getThesaurusType();
        if (thesaurusType == ThesaurusMetadata.BABELIEN_TYPE) {
            if (withFichothequeSharing) {
                result.add(FICHOTHEQUECORPUS);
            }
        } else if (thesaurusType == ThesaurusMetadata.IDALPHA_TYPE) {
            result.add(WIKIDATA);
        }
        return result;
    }

}
