/* BdfServer - Copyright (c) 2014-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.groups.dom;

import fr.exemole.bdfserver.tools.groups.GroupDefBuilder;
import java.text.ParseException;
import net.mapeadores.util.xml.DomMessages;
import net.mapeadores.util.attr.AttributeUtils;
import net.mapeadores.util.logging.MessageHandler;
import net.mapeadores.util.text.LabelUtils;
import net.mapeadores.util.xml.DOMUtils;
import net.mapeadores.util.xml.ElementHandler;
import org.w3c.dom.Element;


/**
 *
 * @author Vincent Calame
 */
public class GroupDefDOMReader {

    private final GroupDefBuilder groupDefBuilder;
    private final MessageHandler messageHandler;

    public GroupDefDOMReader(GroupDefBuilder groupDefBuilder, MessageHandler messageHandler) {
        this.groupDefBuilder = groupDefBuilder;
        this.messageHandler = messageHandler;
    }

    public void readGroup(Element element_xml) {
        RootHandler rootHandler = new RootHandler();
        DOMUtils.readChildren(element_xml, rootHandler);
    }


    private class RootHandler implements ElementHandler {

        private RootHandler() {
        }

        @Override
        public void readElement(Element element) {
            String tagName = element.getTagName();
            if ((tagName.equals("label")) || (tagName.equals("lib"))) {
                try {
                    LabelUtils.readLabel(element, groupDefBuilder);
                } catch (ParseException ile) {
                    DomMessages.wrongLangAttribute(messageHandler, tagName, element.getAttribute("xml:lang"));
                }
            } else if (tagName.equals("attr")) {
                AttributeUtils.readAttrElement(groupDefBuilder.getAttributesBuilder(), element);
            } else {
                DomMessages.unknownTagWarning(messageHandler, tagName);
            }
        }

    }


}
