/* BdfServer - Copyright (c) 2021-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.roles;

import fr.exemole.bdfserver.api.instruction.PermissionBdfInstructionException;
import fr.exemole.bdfserver.api.roles.PermissionEntry;
import fr.exemole.bdfserver.api.roles.PermissionSummary;
import java.util.Collections;
import java.util.List;
import net.fichotheque.Subset;
import net.fichotheque.SubsetItem;
import net.fichotheque.SubsetKey;
import net.fichotheque.addenda.Document;
import net.fichotheque.album.Illustration;
import net.fichotheque.corpus.Corpus;
import net.fichotheque.corpus.FicheMeta;
import net.mapeadores.util.logging.CommandMessage;
import net.mapeadores.util.logging.LogUtils;


/**
 *
 * @author Vincent Calame
 */
public final class PermissionUtils {

    private PermissionUtils() {

    }

    public static void checkAdmin(PermissionSummary permissionSummary, String actionName) throws PermissionBdfInstructionException {
        if (!permissionSummary.canDo(actionName)) {
            CommandMessage commandMessage = LogUtils.error("_ error.permission.admin");
            PermissionBdfInstructionException permissionException = new PermissionBdfInstructionException(commandMessage);
            throw permissionException;
        }
    }

    public static void checkSubsetAdmin(PermissionSummary permissionSummary, Subset subset) throws PermissionBdfInstructionException {
        if (!permissionSummary.isSubsetAdmin(subset.getSubsetKey())) {
            CommandMessage commandMessage = LogUtils.error("_ error.permission.admin");
            PermissionBdfInstructionException permissionException = new PermissionBdfInstructionException(commandMessage);
            throw permissionException;
        }
    }

    public static void checkSubsetAccess(PermissionSummary permissionSummary, Subset subset) throws PermissionBdfInstructionException {
        if (!permissionSummary.hasAccess(subset)) {
            CommandMessage commandMessage = LogUtils.error("_ error.permission.read", subset.getSubsetKey().toString());
            PermissionBdfInstructionException permissionException = new PermissionBdfInstructionException(commandMessage);
            throw permissionException;
        }
    }

    public static void checkWrite(PermissionSummary permissionSummary, Illustration illustration) throws PermissionBdfInstructionException {
        List<PermissionEntry> list = ListFilterEngine.filter(illustration.getAlbum(), Collections.singletonList((SubsetItem) illustration), permissionSummary);
        if ((list.isEmpty()) || (!list.get(0).isEditable())) {
            CommandMessage commandMessage = LogUtils.error("_ error.permission.write", illustration.getSubsetKey().toString() + "/" + illustration.getId());
            PermissionBdfInstructionException permissionException = new PermissionBdfInstructionException(commandMessage);
            throw permissionException;
        }
    }

    public static void checkWrite(PermissionSummary permissionSummary, Document document) throws PermissionBdfInstructionException {
        List<PermissionEntry> list = ListFilterEngine.filter(document.getAddenda(), Collections.singletonList((SubsetItem) document), permissionSummary);
        if ((list.isEmpty()) || (!list.get(0).isEditable())) {
            CommandMessage commandMessage = LogUtils.error("_ error.permission.write", document.getSubsetKey().toString() + "/" + document.getId());
            PermissionBdfInstructionException permissionException = new PermissionBdfInstructionException(commandMessage);
            throw permissionException;
        }
    }

    public static void checkFicheCreate(PermissionSummary permissionSummary, Corpus corpus) throws PermissionBdfInstructionException {
        SubsetKey subsetKey = corpus.getSubsetKey();
        if (!permissionSummary.canCreate(subsetKey)) {
            CommandMessage commandMessage = LogUtils.error("_ error.permission.createfiche", subsetKey.toString());
            PermissionBdfInstructionException permissionException = new PermissionBdfInstructionException(commandMessage);
            throw permissionException;
        }
    }

    public static void checkWrite(PermissionSummary permissionSummary, FicheMeta ficheMeta) throws PermissionBdfInstructionException {
        if (!permissionSummary.canWrite(ficheMeta)) {
            CommandMessage commandMessage = LogUtils.error("_ error.permission.write", ficheMeta.getGlobalId());
            PermissionBdfInstructionException permissionException = new PermissionBdfInstructionException(commandMessage);
            throw permissionException;
        }
    }

    public static void checkRead(PermissionSummary permissionSummary, FicheMeta ficheMeta) throws PermissionBdfInstructionException {
        if (!permissionSummary.canRead(ficheMeta)) {
            CommandMessage commandMessage = LogUtils.error("_ error.permission.readfiche", ficheMeta.getGlobalId());
            PermissionBdfInstructionException permissionException = new PermissionBdfInstructionException(commandMessage);
            throw permissionException;
        }
    }

}
