/* BdfServer_DirectoryStorage - Copyright (c) 2011-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.storage.directory.implementations;

import fr.exemole.bdfserver.api.storage.BdfUserStorage;
import fr.exemole.bdfserver.api.users.BdfUserPrefs;
import fr.exemole.bdfserver.storage.directory.bdfdata.BdfUserDirectory;
import fr.exemole.bdfserver.storage.directory.bdfdata.BdfdataDirectories;
import fr.exemole.bdfserver.storage.directory.bdfdata.Save;
import fr.exemole.bdfserver.storage.directory.bdfdata.StorageFile;
import fr.exemole.bdfserver.tools.users.BdfUserPrefsBuilder;
import fr.exemole.bdfserver.tools.users.dom.BdfUserPrefsDOMReader;
import net.fichotheque.SubsetKey;
import net.fichotheque.sphere.Redacteur;
import net.fichotheque.sphere.Sphere;
import org.w3c.dom.Document;


/**
 *
 * @author Vincent Calame
 */
public class BdfUserStorageImpl implements BdfUserStorage {

    private BdfdataDirectories bdfdataDirectories;

    public BdfUserStorageImpl(BdfdataDirectories bdfdataDirectories) {
        this.bdfdataDirectories = bdfdataDirectories;
    }

    @Override
    public void saveBdfUserPrefs(Redacteur redacteur, BdfUserPrefs bdfUserPrefs) {
        Save.saveBdfUserPrefs(bdfdataDirectories, redacteur, bdfUserPrefs);
    }

    @Override
    public void removeBdfUser(Sphere sphere, int id) {
        BdfUserDirectory bdfUserDirectory = BdfUserDirectory.getBdfUserDirectory(bdfdataDirectories, sphere.getSubsetKey(), id);
        bdfUserDirectory.delete();
    }

    @Override
    public BdfUserPrefs getBdfUserPrefs(Redacteur redacteur) {
        StorageFile storageFile = BdfUserDirectory.getPrefsStorageFile(bdfdataDirectories, redacteur.getSubsetKey(), redacteur.getId());
        if (!storageFile.exists()) {
            return null;
        }
        Document doc = storageFile.readDocument();
        BdfUserPrefsBuilder bdfUserPrefsBuilder = new BdfUserPrefsBuilder();
        BdfUserPrefsDOMReader domReader = new BdfUserPrefsDOMReader(redacteur.getFichotheque(), bdfUserPrefsBuilder);
        domReader.readBdfUserPrefs(doc.getDocumentElement());
        return bdfUserPrefsBuilder.toBdfUserPrefs();
    }

    @Override
    public void removeSphere(SubsetKey sphereKey) {
        BdfUserDirectory.deleteSphereDir(bdfdataDirectories, sphereKey);
    }

}
