/* BdfServer_HtmlProducers - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.mailing;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfCommandResult;
import fr.exemole.bdfserver.api.instruction.BdfInstructionConstants;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.instruction.BdfParameters;
import fr.exemole.bdfserver.api.instruction.OutputParameters;
import fr.exemole.bdfserver.api.interaction.domains.MailingDomain;
import fr.exemole.bdfserver.commands.mailing.SendCommand;
import fr.exemole.bdfserver.email.EmailBuffer;
import fr.exemole.bdfserver.email.SendReport;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import net.mapeadores.util.html.HtmlProducer;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public final class MailingHtmlProducerFactory {

    private MailingHtmlProducerFactory() {
    }

    public static HtmlProducer getHtmlProducer(OutputParameters parameters) throws BdfInstructionException {
        BdfServerHtmlProducer htmlProducer = getBdfHtmlProducer(parameters);
        if (htmlProducer != null) {
            htmlProducer.setBdfCommandResult(parameters.getBdfCommandResult());
        }
        return htmlProducer;
    }

    private static BdfServerHtmlProducer getBdfHtmlProducer(OutputParameters parameters) throws BdfInstructionException {
        String page = parameters.getOutput();
        BdfServer bdfServer = parameters.getBdfServer();
        RequestMap requestMap = parameters.getRequestMap();
        BdfCommandResult bdfCommandResult = parameters.getBdfCommandResult();
        switch (page) {
            case MailingDomain.SEND_FORM_PAGE: {
                SendCommand.testSmtpManager(bdfServer);
                EmailBuffer emailBuffer = getEmailBuffer(parameters, requestMap, bdfCommandResult);
                return new SendFormHtmlProducer(parameters, emailBuffer);
            }
            case MailingDomain.SEND_REPORT_PAGE: {
                SendCommand.testSmtpManager(bdfServer);
                EmailBuffer emailBuffer = getEmailBuffer(parameters, requestMap, bdfCommandResult);
                SendReport sendReport = null;
                if (bdfCommandResult != null) {
                    sendReport = (SendReport) bdfCommandResult.getResultObject(BdfInstructionConstants.SENDREPORT_OBJ);
                }
                return new SendReportHtmlProducer(parameters, emailBuffer, sendReport);
            }
            default:
                return null;
        }
    }

    private static EmailBuffer getEmailBuffer(BdfParameters parameters, RequestMap requestMap, BdfCommandResult bdfCommandResult) throws BdfInstructionException {
        EmailBuffer emailBuffer = null;
        if (bdfCommandResult != null) {
            emailBuffer = (EmailBuffer) bdfCommandResult.getResultObject(BdfInstructionConstants.EMAILBUFFER_OBJ);
        }
        if (emailBuffer == null) {
            emailBuffer = SendCommand.buildFromRequest(parameters.getBdfServer(), parameters.getBdfUser(), parameters.getPermissionSummary(), requestMap, true);
        }
        return emailBuffer;
    }

}
