/* global BDF */

BDF.Appelant = {};

BDF.Appelant.JsManagerInclude = ["_ @title_thesaurus@"];

BDF.Appelant.init = function ($element) {
    BDF.$($element, {appelantRole: "input"}).each(function () {
        var $appelant = $(this);
        var id = $appelant.attr("id");
        if (!id) {
            return;
        }
        var type = $appelant.attr("data-appelant-type");
        if (!_isValidType(type)) {
            return;
        }
        if ($appelant.data("appelantInitialized")) {
            return;
        } else {
            $appelant.data("appelantInitialized", true);
        }
        $appelant.data("type", type);
        var options = {};
        var limit = $appelant.attr("data-appelant-limit");
        if (limit) {
            options.limit = limit;
        }
        var subsets = $appelant.attr("data-appelant-subsets");
        if (subsets) {
            options.subsets = subsets;
        }
        if (type === 'redacteur') {
            var sphere = $appelant.attr("data-appelant-sphere");
            if (sphere) {
                options.param = "sphere_" + sphere;
            }
        } else if (type === 'motcle') {
            var wanted = $appelant.attr("data-appelant-wanted");
            if (wanted) {
                options.wanted = wanted;
            }
        } else if (type === 'field') {
            var fieldtype = $appelant.attr("data-appelant-fieldtype");
            if (fieldtype) {
                options.param = fieldtype;
            }
        }
        $appelant.data("options", options);
        var iconId = BDF.generateId();
        var title = BDF.Appelant.getTitle(type, options);
        var $anchor = $appelant;
        var anchorId = $appelant.attr("data-appelant-anchor");
        if (anchorId) {
            $anchor = ("#" + anchorId);
            if ($anchor.length === 0) {
                $anchor = $appelant;
            }
        }
        $("<button/>", {
            type: "button",
            "class": "global-button-Transparent global-button-Transparent32 " + _getActionClass(type),
            id: iconId,
            title: title,
            click: function () {
                BDF.Appelant.pioche(id, type, options);
            }
        }).html("<span class='global-button-Icon'></span>").insertAfter($anchor);
        $appelant.data("icon", iconId);
    });
    BDF.$($element, {appelantRole: "subset-select"}).change(function () {
        var subsets = new Array();
        subsets.push(this.options[this.selectedIndex].value);
        $($(this).attr("data-appelant-target")).each(function () {
            var $this = $(this);
            var options = $this.data("options");
            options.subsets = subsets;
            var newTitle = BDF.Appelant.getTitle($this.data("type"), options);
            $$($this.data("icon")).attr("title", newTitle);
        });
    });
    
    function _isValidType(type) {
        switch(type) {
            case "redacteur":
            case "motcle":
            case "field":
            case "fiche":
                return true;
            default :
                return false;
        }
    }
    
    function _getActionClass(type) {
        switch(type) {
            case "redacteur":
                return "action-pioche-Redacteur";
            case "motcle":
                return "action-pioche-Motcle";
            case "field":
                return "action-pioche-Field";
            case "fiche":
                return "action-pioche-Fiche";
        }
    }
};

BDF.Appelant.pioche = function (appelantId, piocheType, options) {
    var dialogUrl = "pioche?page=" + _getPiochePath(piocheType) + "&appelant=" + appelantId;
    if (options.hasOwnProperty("limit")) {
        dialogUrl += "&limit=" + options.limit;
    }
    if (options.hasOwnProperty("param")) {
        dialogUrl += "&param=" + options.param;
    }
    if (options.hasOwnProperty("wanted")) {
        dialogUrl += "&wanted=" + options.wanted;
    }
    dialogUrl += "&subsets=";
    if (options.hasOwnProperty("subsets")) {
        dialogUrl += options.subsets;
    }
    var dialogName = "pioche_" + appelantId;
    var width = 430;
    var height = 510;
    var w = window.open(dialogUrl, dialogName, "resizable=yes,width=" + width + ",height=" + height + ",scrollbars");
    w.focus();
    
    function _getPiochePath(type) {
        switch(type) {
            case "redacteur":
                return "redacteur";
            case "motcle":
                return "motcle";
            case "field":
                return "field";
            case "fiche":
                return "fiche";
        }
    }
};

BDF.Appelant.getTitle = function (type, options) {
    var messageKey = _getMessageKey(type, options);
    var title = BDF.Loc.get(messageKey);
    if ((options.hasOwnProperty("subsets")) && (options.subsets.length === 1)) {
        var remplacement = BDF.Loc.get("subset:thesaurus_" + options.subsets[0]);
        var idx = title.indexOf("{0}");
        if (idx !== -1) {
            title = title.substring(0, idx) + remplacement + title.substring(idx + 3);
        }
    }
    return title;
    
    function _getMessageKey(type, options) {
         switch(type) {
            case "redacteur":
                return "_ link.pioche.redacteur";
            case "motcle":
                if ((!options.hasOwnProperty("subsets")) || (options.subsets.length === 0)) {
                    return "_ link.pioche.motcle_all";
                } else if (options.subsets.length === 1) {
                    return "_ link.pioche.motcle_one";
                } else {
                    return "_ link.pioche.motcle_selection";
                }
            case "field":
                if ((options.param) && (options.param === "datation")) {
                    return "_ link.pioche.field_datation";
                } else {
                    return "_ link.pioche.field";
                }
            case "fiche":
                if ((!options.hasOwnProperty("subsets")) || (options.subsets.length === 0)) {
                    return "_ link.pioche.fiche_all";
                } else if (options.subsets.length === 1) {
                    return "_ link.pioche.fiche_one";
                } else {
                    return "_ link.pioche.fiche_selection";
                }
        }
    }
};


$(function () {
    BDF.Appelant.init($("body"));
});